/*
 * Copyright (C) 2017  Kevin Whitaker <eyecreate@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#ifndef PLAYERINTERFACE_H
#define PLAYERINTERFACE_H

#include <Wt/WContainerWidget>
#include <Wt/WTabWidget>
#include <Wt/WHBoxLayout>
#include <Wt/WVBoxLayout>
#include "../WebInterface.h"
#include <Wt/WPushButton>
#include <Wt/WText>
#include <Wt/WProgressBar>
#include <Wt/WTimer>
#include "TrackDetails.h"

class PlayerInterface : public Wt::WContainerWidget
{
public:
    PlayerInterface(WebInterface* app);
    WebInterface* app;
    
    Wt::WVBoxLayout* interfaceLayout;
    Wt::WHBoxLayout* playControlLayout;
    Wt::WContainerWidget* playControlWidget;
    Wt::WVBoxLayout* voteControlLayout;
    
    //Play controls
    TrackDetails* currentTrackDetails;
    Wt::WProgressBar* currentTrackProgress;
    Wt::WTimer* trackProgress;
    Wt::WHBoxLayout* currentTrackLayout;
    Wt::WContainerWidget* currentTrackContainer;
    Wt::WPushButton* playpause;
    Wt::WContainerWidget* skipControls;
    Wt::WPushButton* skipRequest;
    Wt::WPushButton* skipDeny;
    
    //TabView
    Wt::WTabWidget* mainDisplay;
    
    //Vote Controls
    Wt::WContainerWidget* voteMetaContainer;
    Wt::WVBoxLayout* voteMetaLayout;
    Wt::WContainerWidget* voteControlContainer;
    Wt::WContainerWidget* voteTracksContainer;
    Wt::WText* voteHeader;
    Wt::WVBoxLayout* voteTracksLayout;
    Wt::WHBoxLayout* track1;
    Wt::WHBoxLayout* track2;
    Wt::WHBoxLayout* track3;
    TrackDetails* track1details;
    Wt::WPushButton* track1vote;
    Wt::WText* track1votecount;
    TrackDetails* track2details;
    Wt::WPushButton* track2vote;
    Wt::WText* track2votecount;
    TrackDetails* track3details;
    Wt::WPushButton* track3vote;
    Wt::WText* track3votecount;
    
    bool isPaused = false;
    //TODO:put in controls for requesting/admin skip and adding users as admin.
    
    void playpauseClicked();
    void playpauseUpdated();
    void skipRequestClicked();
    void skipDenyClicked();
    void vote1clicked();
    void vote2clicked();
    void vote3clicked();
    void updateDetailsFromServer(AudioTrack track);
    void updateVoteableTracksFromServer(std::list<AudioTrack> tracks);
    void updateVoteTrackState();
    void updateProgressFromTimer();
    void updateSkipRequestedFromServer();
    void updateSkipDeniedFromServer();
    void updateVotingEnded(AudioTrack winner);
    void updateVoteCount(AudioTrack trackVoted);
};

#endif // PLAYERINTERFACE_H
